import "./tasks/fastqc.wdl" as fastqc
import "./tasks/fastqscreen.wdl" as fastqscreen
import "./tasks/hisat2.wdl" as hisat2
import "./tasks/samtools.wdl" as samtools
import "./tasks/stringtie.wdl" as stringtie
import "./tasks/ballgown.wdl" as ballgown

workflow {{ project_name }} {

	File read1
	File read2
    File idx
	String idx_prefix
    File gtf
    String fastqc_docker
    String fastqc_cluster
	String fastqscreen_docker
    String fastqscreen_cluster
	String hisat2_docker
	String hisat2_cluster
	String stringtie_docker
	String stringtie_cluster
	String samtools_docker
	String samtools_cluster
	String ballgown_docker
	String ballgown_cluster
	
	
	call fastqc.fastqc as fastqc {
		input:
		read1=read1,
		read2=read2,
		docker = fastqc_docker,
		cluster = fastqc_cluster
		}
			
	call fastqscreen.fastqscreen as fastqscreen {
		input:
		read1=read1,
		read2=read2,
		docker = fastqscreen_docker,
		cluster = fastqscreen_cluster,
		screen_ref_dir=screen_ref_dir,
		fastq_screen_conf=fastq_screen_conf
		}	
	
	call hisat2.hisat2 as hisat2 {
		input: 
		docker = hisat2_docker,
		cluster = hisat2_cluster,
		idx=idx, 
		idx_prefix=idx_prefix, 
		read_1P=read1, 
		read_2P=read2
	}

    call samtools.samtools as samtools {
        input: 
		docker = samtools_docker,
		cluster = samtools_cluster,
		sam = hisat2.sam
	}

    call stringtie.stringtie as stringtie {
        input: 
		docker = stringtie_docker,
		cluster = stringtie_cluster,
		gtf = gtf, 
		bam = samtools.out_bam
	}   

	call ballgown.ballgown as ballgown {
		input: 
		docker = ballgown_docker,
		cluster = ballgown_cluster,
		ballgown = stringtie.ballgown,
		gene_abundance = stringtie.gene_abundance
	} 
	
}


